@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 
 import unittest
 from collections import OrderedDict
+from copy import copy
 from datetime import datetime, timedelta
 
 from mock import Mock, patch
@@ -12,7 +13,6 @@ import six
 
 import dateparser
 from dateparser import date
-from dateparser.date import get_last_day_of_month
 from dateparser.conf import settings
 
 from tests import BaseTestCase
@@ -274,18 +274,29 @@ class TestParseWithFormatsFunction(BaseTestCase):
 
     @parameterized.expand([
         param(date_string='August 2014', date_formats=['%B %Y'],
-              expected_year=2014, expected_month=8),
+              expected_year=2014, expected_month=8, today_day=12,
+              prefer_day_of_month='first', expected_day=1),
+        param(date_string='August 2014', date_formats=['%B %Y'],
+              expected_year=2014, expected_month=8, today_day=12,
+              prefer_day_of_month='last', expected_day=31),
+        param(date_string='August 2014', date_formats=['%B %Y'],
+              expected_year=2014, expected_month=8, today_day=12,
+              prefer_day_of_month='current', expected_day=12),
     ])
-    def test_should_use_last_day_of_month_for_dates_without_day(
-        self, date_string, date_formats, expected_year, expected_month
+    def test_should_use_correct_day_from_settings_for_dates_without_day(
+        self, date_string, date_formats, expected_year, expected_month,
+        today_day, prefer_day_of_month, expected_day
     ):
-        self.given_now(2014, 8, 12)
-        self.when_date_is_parsed_with_formats(date_string, date_formats)
+        self.given_now(2014, 8, today_day)
+        settings_mod = copy(settings)
+        settings_mod.PREFER_DAY_OF_MONTH = prefer_day_of_month
+        self.when_date_is_parsed_with_formats(date_string, date_formats, settings_mod)
         self.then_date_was_parsed()
         self.then_parsed_period_is('month')
         self.then_parsed_date_is(datetime(year=expected_year,
                                           month=expected_month,
-                                          day=get_last_day_of_month(expected_year, expected_month)))
+                                          day=expected_day))
+
 
     @parameterized.expand([
         param(date_string='25-03-14', date_formats='%d-%m-%y', expected_result=datetime(2014, 3, 25)),
@@ -303,9 +314,10 @@ class TestParseWithFormatsFunction(BaseTestCase):
         datetime_mock.now = Mock(return_value=now)
         datetime_mock.today = Mock(return_value=now)
         self.add_patch(patch('dateparser.date.datetime', new=datetime_mock))
+        self.add_patch(patch('dateparser.utils.datetime', new=datetime_mock))
 
-    def when_date_is_parsed_with_formats(self, date_string, date_formats):
-        self.result = date.parse_with_formats(date_string, date_formats, settings)
+    def when_date_is_parsed_with_formats(self, date_string, date_formats, custom_settings=None):
+        self.result = date.parse_with_formats(date_string, date_formats, custom_settings or settings)
 
     def then_date_was_not_parsed(self):
         self.assertIsNotNone(self.result)
@@ -437,6 +449,12 @@ class TestDateDataParser(BaseTestCase):
             TypeError, ["Date formats should be list, tuple or set of strings",
                         "'{}' object is not iterable".format(type(date_formats).__name__)])
 
+    def test_parsing_date_using_unknown_parsers_must_raise_error(self):
+        self.given_parser(settings={'PARSERS': ['foo']})
+        self.when_date_string_is_parsed('2020-02-19')
+        self.then_error_was_raised(
+            ValueError, ["Unknown parsers found in the PARSERS setting: foo"])
+
     @parameterized.expand([
         param(date_string={"date": "12/11/1998"}),
         param(date_string=[2017, 12, 1]),
